pub struct KillPortArgs {
pub ports: Vec<u16>,
pub mode: Mode,
pub signal: KillportSignal,
pub verbose: Verbosity<WarnLevel>,
pub dry_run: bool,
pub no_fail: bool,
}Expand description
killport utility.
Fields
ports: Vec<u16>A list of port numbers to kill processes on.
mode: ModeOperation mode.
signal: KillportSignalAn option to specify the type of signal to be sent.
verbose: Verbosity<WarnLevel>A verbosity flag to control the level of logging output.
dry_run: boolDry-run flag to only display what would be done without taking action.
no_fail: boolDo not exit with an error if no matching process or container is found.